package com.bjtdba.userCenter.dao;

import org.apache.ibatis.annotations.Mapper;
import org.springframework.stereotype.Repository;

@Repository
@Mapper
public interface MerchantDao {

    int selectUserMerchantByUid(Integer uid);

    Double getoffLine(Integer uid);

    Integer getoffLineCount(Integer uid);

    /**
     *  验证商品是否存在
     * @param id
     * @return
     */
    Integer countProduct(Integer id);

    /**
     * 验证商铺是否存在
     * @param id
     * @return
     */
    Integer countMerchanet(Integer id);


    /**
     * 产品关注+1
     * @param id
     * @return
     */
    int  addCountProduct(Integer id);

    /**
     * 商铺关注+1
     * @param id
     * @return
     */
    int  addCountMerchant(Integer id);


    /**
     * 取消产品关注-1
     * @param id
     * @return
     */
    int  delCountProduct(Integer id);

    /**
     * 取消商铺关注-1
     * @param id
     * @return
     */
    int  delCountMerchant(Integer id);

}
